%define major	%(echo %{version}|cut -d. -f1,2)
%define tcltk	8.6
%define app_id	io.github.benini.%{name}

Summary:	Shane's Chess Information Database
Name:		scid
Version:	5.1.0
Release:	%mkrel 2
Group:		Games/Boards
License:	GPLv2+
URL:		https://scid.sourceforge.net/
Source0:	https://sourceforge.net/projects/scid/files/Scid/Scid%20%{major}/scid%{version}-src.zip
Source1:	%{name}.png
Patch0:		scid-5.1.0-mga-gtest.patch
Patch1:		scid-5.1.0-mga-installdir.patch
Patch2:		scid-5.1.0-convert-python2-to-pyton3.patch

BuildRequires:	cmake
BuildRequires:	tcl-devel
BuildRequires:	tk-devel
BuildRequires:	pkgconfig(gtest)

Recommends:	nail
Recommends:	tcl-snack

%description
Scid (Shane's Chess Information Database) is a free chess database app.

With Scid you can maintain a database of chess games, search games by
many criteria, view graphical trends, and produce printable reports on
players and openings.

You can also analyze games with the Xboard or UCI compatible chess
program, and even use Scid to study endings with endgame tablebases.

With Scid you can also play against various engines, or on the Internet.

%prep
%autosetup -p1

# Force loading of system Tk library
sed -e "/^package require Tk /i load %{_libdir}/libtk%{tcltk}.so" \
    -i tcl/start.tcl

# Add building togaII engine directly into CMakeLists.txt file
cat << EOF | sed -e "/phalanx-scid DESTINATION bin/ r /dev/stdin" -i CMakeLists.txt

# engine togaII
file(GLOB TOGAII_SRC engines/togaII1.2.1a/src/*.cpp)
add_executable(togaII \${TOGAII_SRC})
set_target_properties(togaII PROPERTIES COMPILE_FLAGS "-w")
install(TARGETS togaII DESTINATION bin)
EOF

%build
%cmake -DGTEST=ON \
       -DSPELLCHKVALIDATE=ON
%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_iconsdir}/hicolor/scalable/apps
cp flatpak/%{app_id}.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps
mkdir -p %{buildroot}%{_metainfodir}
cp flatpak/%{app_id}.appdata.xml %{buildroot}%{_metainfodir}

# Desktop entry
desktop-file-install flatpak/%{app_id}.desktop \
    --set-key=Exec --set-value="scid %f" \
    --dir %{buildroot}%{_datadir}/applications

# Licenses:
cp engines/phalanx-scid/COPYING COPYING_phalanx
cp engines/togaII*/copying.txt COPYING_togaII
cp src/polyglot/copying.txt COPYING_polyglot

%check
build/gtest/scid_tests

%files
%license COPYING{,_phalanx,_togaII,_polyglot}
%doc ChangeLog README.md help/
%{_bindir}/*
%{_libdir}/*.so
%{_datadir}/%{name}/
%{_datadir}/applications/%{app_id}.desktop
%{_iconsdir}/hicolor/scalable/apps/%{app_id}.svg
%{_metainfodir}/%{app_id}.appdata.xml


%changelog
* Sun May 18 2025 daviddavid <daviddavid> 5.1.0-2.mga10
+ Revision: 2184515
- fix python scripts for python-3.13 (thanks to Aurelian R)
- there is no more conflict with scidvspc

* Sat Jan 18 2025 daviddavid <daviddavid> 5.1.0-1.mga10
+ Revision: 2139661
- new version: 5.1.0 (thanks to Aurelian R, mga#33937)

* Tue Mar 29 2022 umeabot <umeabot> 4.7.0-3.mga9
+ Revision: 1832992
- Mageia 9 Mass Rebuild
+ pterjan <pterjan>
- Remove usage of obsolete macros (https://github.com/rpm-software-management/rpm/issues/1211)

* Sat Mar 21 2020 danf <danf> 4.7.0-2.mga8
+ Revision: 1558659
- tests.patch to fix tests on ARM
- Update to version 4.7.0
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 4.6.4-2.mga7
+ Revision: 1300941
- Mageia 7 Mass Rebuild

* Sun Apr 22 2018 kekepower <kekepower> 4.6.4-1.mga7
+ Revision: 1221242
- Update to version 4.6.4

* Wed Sep 20 2017 cjw <cjw> 4.6.2-4.mga7
+ Revision: 1156196
- pass optflags to make, to fix debug packages

* Mon Oct 03 2016 pterjan <pterjan> 4.6.2-3.mga6
+ Revision: 1058211
- Fix build when char defaults to unsigned (e.g. arm)

* Sat Feb 20 2016 umeabot <umeabot> 4.6.2-2.mga6
+ Revision: 971989
- Mageia 6 Mass Rebuild

* Wed Oct 21 2015 danf <danf> 4.6.2-1.mga6
+ Revision: 894011
- Upgraded to ver. 4.6.2
- Enabled sound

* Wed Oct 15 2014 umeabot <umeabot> 4.4-4.mga5
+ Revision: 747086
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.4-3.mga5
+ Revision: 689054
- Mageia 5 Mass Rebuild

* Tue Oct 22 2013 umeabot <umeabot> 4.4-2.mga4
+ Revision: 545003
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 dams <dams> 4.4-1.mga4
+ Revision: 500588
- new version 4.4

* Mon Jan 14 2013 umeabot <umeabot> 4.3-4.mga3
+ Revision: 381813
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jul 26 2012 dams <dams> 4.3-3.mga3
+ Revision: 274516
- Add a conflict with 'scidvspc'

* Thu Jul 26 2012 dams <dams> 4.3-2.mga3
+ Revision: 274494
- update '%%summary' and '%%description'

* Fri Jul 20 2012 dams <dams> 4.3-1.mga3
+ Revision: 272852
- imported package scid

